# magictype
Generating type hints easy

## why
To use mypy we need  perform such things like write type hints, but we can generate based on call of funcitons during code execution.

## how
I use the module ast to parse, insert annotations and unparse

## promess document perfectly and comment out everything